@@ -20,6 +20,7 @@ namespace isptr
 
     //MARK:- ref_counted_flags
 
+    ISPTR_EXPORTED
     enum class ref_counted_flags : unsigned
     {
         none = 0,
@@ -27,62 +28,76 @@ namespace isptr
         single_threaded = 2
     };
 
-    constexpr ref_counted_flags operator|(ref_counted_flags lhs, ref_counted_flags rhs) noexcept
+    ISPTR_EXPORTED constexpr ref_counted_flags operator|(ref_counted_flags lhs, ref_counted_flags rhs) noexcept
         { return ref_counted_flags(unsigned(lhs) | unsigned(rhs)); }
-    constexpr ref_counted_flags operator&(ref_counted_flags lhs, ref_counted_flags rhs) noexcept
+    ISPTR_EXPORTED constexpr ref_counted_flags operator&(ref_counted_flags lhs, ref_counted_flags rhs) noexcept
         { return ref_counted_flags(unsigned(lhs) & unsigned(rhs)); }
-    constexpr ref_counted_flags operator^(ref_counted_flags lhs, ref_counted_flags rhs) noexcept
+    ISPTR_EXPORTED constexpr ref_counted_flags operator^(ref_counted_flags lhs, ref_counted_flags rhs) noexcept
         { return ref_counted_flags(unsigned(lhs) ^ unsigned(rhs)); }
-    constexpr ref_counted_flags operator~(ref_counted_flags arg) noexcept
+    ISPTR_EXPORTED constexpr ref_counted_flags operator~(ref_counted_flags arg) noexcept
         { return ref_counted_flags(~unsigned(arg)); }
 
-    constexpr bool contains(ref_counted_flags val, ref_counted_flags flag) noexcept
+    ISPTR_EXPORTED constexpr bool contains(ref_counted_flags val, ref_counted_flags flag) noexcept
         { return (val & flag) == flag;   }
 
     //MARK:- Forward Declarations
 
+    ISPTR_EXPORTED
     template<ref_counted_flags Flags>
     using default_count_type = std::conditional_t<contains(Flags, ref_counted_flags::provide_weak_references), intptr_t, int>;
 
+    ISPTR_EXPORTED
     template<class Derived, ref_counted_flags Flags = ref_counted_flags::none, class CountType = default_count_type<Flags>>
     class ref_counted;
 
+    ISPTR_EXPORTED
     template<class T, ref_counted_flags Flags = ref_counted_flags::none, class CountType = default_count_type<Flags>>
     class ref_counted_adapter;
 
+    ISPTR_EXPORTED
     template<class T, ref_counted_flags Flags = ref_counted_flags::none, class CountType = default_count_type<Flags>>
     class ref_counted_wrapper;
 
+    ISPTR_EXPORTED
     template<class Derived>
     using weak_ref_counted = ref_counted<Derived, ref_counted_flags::provide_weak_references>;
 
+    ISPTR_EXPORTED
     template<class Derived>
     using weak_ref_counted_adapter = ref_counted_adapter<Derived, ref_counted_flags::provide_weak_references>;
 
+    ISPTR_EXPORTED
     template<class Derived>
     using weak_ref_counted_wrapper = ref_counted_wrapper<Derived, ref_counted_flags::provide_weak_references>;
 
+    ISPTR_EXPORTED
     template<class Derived, class CountType = default_count_type<ref_counted_flags::single_threaded>>
     using ref_counted_st = ref_counted<Derived, ref_counted_flags::single_threaded, CountType>;
 
+    ISPTR_EXPORTED
     template<class Derived, class CountType = default_count_type<ref_counted_flags::single_threaded>>
     using ref_counted_adapter_st = ref_counted_adapter<Derived, ref_counted_flags::single_threaded, CountType>;
 
+    ISPTR_EXPORTED
     template<class Derived, class CountType = default_count_type<ref_counted_flags::single_threaded>>
     using ref_counted_wrapper_st = ref_counted_wrapper<Derived, ref_counted_flags::single_threaded, CountType>;
 
+    ISPTR_EXPORTED
     template<class Derived>
     using weak_ref_counted_st = ref_counted<Derived, ref_counted_flags::provide_weak_references | 
                                                      ref_counted_flags::single_threaded>;
 
+    ISPTR_EXPORTED
     template<class Derived>
     using weak_ref_counted_adapter_st = ref_counted_adapter<Derived, ref_counted_flags::provide_weak_references | 
                                                                      ref_counted_flags::single_threaded>;
 
+    ISPTR_EXPORTED
     template<class Derived>
     using weak_ref_counted_wrapper_st = ref_counted_wrapper<Derived, ref_counted_flags::provide_weak_references |
                                                                      ref_counted_flags::single_threaded>;
 
+    ISPTR_EXPORTED
     template<class Owner>
     class weak_reference;
 
@@ -205,7 +220,7 @@ namespace isptr
         using strong_ptr = intrusive_shared_ptr<strong_value_type, ref_counted_traits>;
         using const_strong_ptr = intrusive_shared_ptr<const strong_value_type, ref_counted_traits>;
 
-        static const bool single_threaded = Owner::single_threaded;
+        static constexpr bool single_threaded = Owner::single_threaded;
 
     private:
         using count_type = std::conditional_t<weak_reference::single_threaded, intptr_t, std::atomic<intptr_t>>;
